@@ -5,16 +5,16 @@ import appdirs
 
 name = "pydatasci"
 
-app_dir_free = appdirs.user_data_dir("pydatasci")
+app_dir_no_trailing_slash = appdirs.user_data_dir("pydatasci")
 # Adds trailing slash or backslashes depending on OS.
-app_dir = os.path.join(app_dir_free, '')
+app_dir = os.path.join(app_dir_no_trailing_slash, '')
 default_config_path = app_dir + "config.json"
 default_db_path = app_dir + "aidb.sqlite3"
 
 
 def check_exists_folder():
 	# If Windows does not have permission to read the folder, it will fail when trailing backslashes \\ provided.
-	app_dir_exists = os.path.exists(app_dir_free)
+	app_dir_exists = os.path.exists(app_dir_no_trailing_slash)
 	if app_dir_exists:
 		print("\n=> Success - the following file path already exists on your system:\n" + app_dir + "\n")
 		return True
@@ -117,7 +117,7 @@ def grant_permissions_folder():
 				# Windows ICACLS permissions: https://www.educative.io/edpresso/what-is-chmod-in-windows
 				# Works in Windows Command Prompt and `os.system()`, but not PowerShell.
 				# Does not work with trailing backslashes \\
-				command = 'icacls "' + app_dir_free + '" /grant users:(F) /c'
+				command = 'icacls "' + app_dir_no_trailing_slash + '" /grant users:(F) /c'
 				os.system(command)
 			else:
 				# posix
